# Moonchart
This package provides backtest performance analysis and charting for [QuantRocket](https://www.quantrocket.com).

## Example tear sheets

### Moonshot backtest:

![Moonchart tear sheet](https://github.com/quantrocket-llc/moonchart/raw/master/docs/tearsheet-details-example.jpg "Example tear sheet created from a Moonshot backtest")

### 1-dimensional single-strategy parameter scan with Moonshot:

![Moonchart 1-d parameter scan tear sheet](https://github.com/quantrocket-llc/moonchart/raw/master/docs/paramscan-1d-example.jpg "Example tear sheet created from a Moonshot 1-d parameter scan")

### 1-dimensional multi-strategy parameter scan with Moonshot:

![Moonchart 1-d multi-strategy parameter scan tear sheet](https://github.com/quantrocket-llc/moonchart/raw/master/docs/paramscan-1d-multistrat-example.jpg "Example tear sheet created from a Moonshot 1-d multi-strategy parameter scan")

### 2-dimensional parameter scan with Moonshot:

![Moonchart 2-d parameter scan tear sheet](https://github.com/quantrocket-llc/moonchart/raw/master/docs/paramscan-2d-example.jpg "Example tear sheet created from a Moonshot 2-d parameter scan")

## Installation and Usage

For installation and usage documentation, please visit: https://www.quantrocket.com/docs/

## License

Moonchart is distributed under the Apache 2.0 License. See the LICENSE file in the release for details.
